from random_unicode_emoji.random_unicode_emoji import random_emoji

__author__ = 'Nic Jones'
__email__ = 'nic@nicpjones.com'
__version__ = '2.4'
__doc__ = """
Random Unicode Emoji
====================
A Python package and function to retrieve a random Unicode emoji.

Install
-------
Install the package:
>>> pip install random-unicode-emoji

Usage
-----
Use the package:
>>> # Import the Library
>>> from random_unicode_emoji import random_emoji
>>> # Use the Function
>>> print(random_emoji())
>>> # Use Specific Version
>>> print(random_emoji(version="15.0"))

Upgrade
-------
Upgrade the package to the version:
>>> pip install random-unicode-emoji -U
"""
